@@ -656,9 +656,9 @@ function HandleSync($backend, $protocolversion, $devid) {
         $encoder->startTag(SYNC_FOLDERS);
         {
             foreach($collections as $collection) {
-            	// initialize exporter to get changecount
-            	$changecount = 0;
-            	if(isset($collection["getchanges"])) {
+                // initialize exporter to get changecount
+                $changecount = 0;
+                if(isset($collection["getchanges"]) || $collection["synckey"] == "0") {
                     // Use the state from the importer, as changes may have already happened
                     $exporter = $backend->GetExporter($collection["collectionid"]);
 
@@ -773,7 +773,7 @@ function HandleSync($backend, $protocolversion, $devid) {
                     if (isset($exporter) && $exporter)
                         $state = $exporter->GetState();
 
-                    // nothing exported, but possible imported
+                    // nothing exported, but possibly imported
                     else if (isset($importer) && $importer)
                         $state = $importer->GetState();
 
@@ -953,16 +953,22 @@ function HandlePing($backend, $devid) {
             while($decoder->getElementStartTag(SYNC_PING_FOLDER)) {
                 $collection = array();
 
-                if($decoder->getElementStartTag(SYNC_PING_SERVERENTRYID)) {
-                    $collection["serverid"] = $decoder->getElementContent();
-                    $decoder->getElementEndTag();
-                }
-                if($decoder->getElementStartTag(SYNC_PING_FOLDERTYPE)) {
-                    $collection["class"] = $decoder->getElementContent();
-                    $decoder->getElementEndTag();
-                }
+                while(1) {
+                    if($decoder->getElementStartTag(SYNC_PING_SERVERENTRYID)) {
+                        $collection["serverid"] = $decoder->getElementContent();
+                        $decoder->getElementEndTag();
+                    }
+                    if($decoder->getElementStartTag(SYNC_PING_FOLDERTYPE)) {
+                        $collection["class"] = $decoder->getElementContent();
+                        $decoder->getElementEndTag();
+                    }
 
-                $decoder->getElementEndTag();
+                    $e = $decoder->peek();
+                    if($e[EN_TYPE] == EN_TYPE_ENDTAG) {
+                        $decoder->getElementEndTag();
+                        break;
+                    }
+                }
 
                 // initialize empty state
                 $collection["state"] = "";
@@ -1656,12 +1662,6 @@ function HandleSearch($backend, $devid, $protocolversion) {
                                     $encoder->endTag();
                                 }
 
-                                if (isset($u[SYNC_GAL_ALIAS])) {
-                                    $encoder->startTag(SYNC_GAL_ALIAS);
-                                    $encoder->content($u[SYNC_GAL_ALIAS]);
-                                    $encoder->endTag();
-                                }
-
                                 if (isset($u[SYNC_GAL_OFFICE])) {
                                     $encoder->startTag(SYNC_GAL_OFFICE);
                                     $encoder->content($u[SYNC_GAL_OFFICE]);
@@ -1680,15 +1680,9 @@ function HandleSearch($backend, $devid, $protocolversion) {
                                     $encoder->endTag();
                                 }
 
-                                if (isset($u[SYNC_GAL_HOMEPHONE])) {
-                                    $encoder->startTag(SYNC_GAL_HOMEPHONE);
-                                    $encoder->content($u[SYNC_GAL_HOMEPHONE]);
-                                    $encoder->endTag();
-                                }
-
-                                if (isset($u[SYNC_GAL_MOBILEPHONE])) {
-                                    $encoder->startTag(SYNC_GAL_MOBILEPHONE);
-                                    $encoder->content($u[SYNC_GAL_MOBILEPHONE]);
+                                if (isset($u[SYNC_GAL_ALIAS])) {
+                                    $encoder->startTag(SYNC_GAL_ALIAS);
+                                    $encoder->content($u[SYNC_GAL_ALIAS]);
                                     $encoder->endTag();
                                 }
 
@@ -1701,6 +1695,18 @@ function HandleSearch($backend, $devid, $protocolversion) {
                                 $encoder->content((isset($u[SYNC_GAL_LASTNAME]))?$u[SYNC_GAL_LASTNAME]:"No name");
                                 $encoder->endTag();
 
+                                if (isset($u[SYNC_GAL_HOMEPHONE])) {
+                                    $encoder->startTag(SYNC_GAL_HOMEPHONE);
+                                    $encoder->content($u[SYNC_GAL_HOMEPHONE]);
+                                    $encoder->endTag();
+                                }
+
+                                if (isset($u[SYNC_GAL_MOBILEPHONE])) {
+                                    $encoder->startTag(SYNC_GAL_MOBILEPHONE);
+                                    $encoder->content($u[SYNC_GAL_MOBILEPHONE]);
+                                    $encoder->endTag();
+                                }
+
                                 $encoder->startTag(SYNC_GAL_EMAILADDRESS);
                                 $encoder->content((isset($u[SYNC_GAL_EMAILADDRESS]))?$u[SYNC_GAL_EMAILADDRESS]:"");
                                 $encoder->endTag();
